@@ -31,9 +31,8 @@ import Network.HTTP.Conduit (def)
 -- Don't forget to add new modules to your cabal file!
 import Handler.RootR
 import Handler.JournalR
-import Handler.JournalEditR
-import Handler.JournalEntriesR
 import Handler.RegisterR
+import Handler.SidebarR
 
 import Hledger.Web.Options (WebOpts(..), defwebopts)
 import Hledger.Data (Journal, nulljournal)
@@ -78,7 +77,7 @@ makeFoundation conf = do
 getApplicationDev :: IO (Int, Application)
 getApplicationDev = do
   f <- journalFilePathFromOpts defcliopts
-  j <- either error' id `fmap` readJournalFile Nothing Nothing f
+  j <- either error' id `fmap` readJournalFile Nothing Nothing True f
   defaultDevelApp loader (makeApplication defwebopts j)
   where
     loader = Yesod.Default.Config.loadConfig (configSettings Development)
