@@ -16,7 +16,7 @@ import Hledger.Web.Options
 
 
 -- | The journal entries view, with sidebar.
-getJournalEntriesR :: Handler RepHtml
+getJournalEntriesR :: Handler Html
 getJournalEntriesR = do
   vd@VD{..} <- getViewData
   staticRootUrl <- (staticRoot . settings) <$> getYesod
@@ -33,14 +33,32 @@ getJournalEntriesR = do
   ^{sidecontent}
  <div#main.journal>
   <div#maincontent>
-   <h2#contenttitle>#{title}
    ^{searchform vd}
+   <h2#contenttitle>#{title}
    ^{maincontent}
   ^{addform staticRootUrl vd}
   ^{editform vd}
   ^{importform}
 |]
 
-postJournalEntriesR :: Handler RepHtml
+postJournalEntriesR :: Handler Html
 postJournalEntriesR = handlePost
 
+-- | Render an "EntriesReport" as html for the journal entries view.
+entriesReportAsHtml :: WebOpts -> ViewData -> EntriesReport -> HtmlUrl AppRoute
+entriesReportAsHtml _ vd items = [hamlet|
+<table.entriesreport>
+ $forall i <- numbered items
+  ^{itemAsHtml vd i}
+ |]
+ where
+   itemAsHtml :: ViewData -> (Int, EntriesReportItem) -> HtmlUrl AppRoute
+   itemAsHtml _ (n, t) = [hamlet|
+<tr.item.#{evenodd}>
+ <td.transaction>
+  <pre>#{txn}
+ |]
+     where
+       evenodd = if even n then "even" else "odd" :: String
+       txn = trimnl $ showTransaction t where trimnl = reverse . dropWhile (=='\n') . reverse
+
